@@ -23,7 +23,7 @@ from oslo_serialization import jsonutils
 
 from horizon import exceptions
 
-log = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class AjaxError(Exception):
@@ -75,7 +75,9 @@ class JSONResponse(_RestResponse):
 
 def ajax(authenticated=True, data_required=False,
          json_encoder=json.JSONEncoder):
-    '''Provide a decorator to wrap a view method so that it may exist in an
+    """Decorator to allow the wrappered view to exist in an AJAX environment.
+
+    Provide a decorator to wrap a view method so that it may exist in an
     entirely AJAX environment:
 
     - data decoded from JSON as input and data coded as JSON as output
@@ -98,7 +100,7 @@ def ajax(authenticated=True, data_required=False,
 
     Methods returning nothing (or None explicitly) will result in a 204 "NO
     CONTENT" being returned to the caller.
-    '''
+    """
     def decorator(function, authenticated=authenticated,
                   data_required=data_required):
         @functools.wraps(function,
@@ -136,16 +138,22 @@ def ajax(authenticated=True, data_required=False,
                         http_status = getattr(e, attr)
                         break
                 else:
-                    log.exception('HTTP exception with no status/code')
+                    LOG.exception('HTTP exception with no status/code')
                     return JSONResponse(str(e), 500)
                 return JSONResponse(str(e), http_status)
             except Exception as e:
-                log.exception('error invoking apiclient')
+                LOG.exception('error invoking apiclient')
                 return JSONResponse(str(e), 500)
 
         return _wrapped
     return decorator
 
+PARAM_MAPPING = {
+    'None': None,
+    'True': True,
+    'False': False
+}
+
 
 def parse_filters_kwargs(request, client_keywords=None):
     """Extract REST filter parameters from the request GET args.
@@ -158,8 +166,28 @@ def parse_filters_kwargs(request, client_keywords=None):
     kwargs = {}
     client_keywords = client_keywords or {}
     for param in request.GET:
+        param_value = PARAM_MAPPING.get(request.GET[param], request.GET[param])
         if param in client_keywords:
-            kwargs[param] = request.GET[param]
+            kwargs[param] = param_value
         else:
-            filters[param] = request.GET[param]
+            filters[param] = param_value
     return filters, kwargs
+
+
+def post2data(func):
+    """Decorator to restore original form values along with their types.
+
+    The sole purpose of this decorator is to restore original form values
+    along with their types stored on client-side under key $$originalJSON.
+    This in turn prevents the loss of field types when they are passed with
+    header 'Content-Type: multipart/form-data', which is needed to pass a
+    binary blob as a part of POST request.
+    """
+    def wrapper(self, request):
+        request.DATA = request.POST
+        if '$$originalJSON' in request.POST:
+            request.DATA = json.loads(request.POST['$$originalJSON'])
+
+        return func(self, request)
+
+    return wrapper
