@@ -14,7 +14,8 @@ import mock
 
 from django.core.urlresolvers import reverse
 from django import http
-from mox3.mox import IsA  # noqa
+from django.utils import html
+from mox3.mox import IsA
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.admin.aggregates import constants
@@ -78,10 +79,12 @@ class CreateAggregateWorkflowTests(BaseAggregateWorkflowTests):
     @test.create_stubs({api.nova: ('host_list', 'aggregate_details_list',
                                    'aggregate_create'), })
     def _test_generic_create_aggregate(self, workflow_data, aggregate,
+                                       existing_aggregates=(),
                                        error_count=0,
                                        expected_error_message=None):
         api.nova.host_list(IsA(http.HttpRequest)).AndReturn(self.hosts.list())
-        api.nova.aggregate_details_list(IsA(http.HttpRequest)).AndReturn([])
+        api.nova.aggregate_details_list(IsA(http.HttpRequest)) \
+            .AndReturn(existing_aggregates)
         if not expected_error_message:
             api.nova.aggregate_create(
                 IsA(http.HttpRequest),
@@ -111,9 +114,32 @@ class CreateAggregateWorkflowTests(BaseAggregateWorkflowTests):
         workflow_data = self._get_create_workflow_data(aggregate)
         workflow_data['name'] = ''
         workflow_data['availability_zone'] = ''
-        self._test_generic_create_aggregate(workflow_data, aggregate, 1,
+        self._test_generic_create_aggregate(workflow_data, aggregate, (), 1,
                                             u'This field is required')
 
+    def test_create_aggregate_fails_missing_fields_existing_aggregates(self):
+        aggregate = self.aggregates.first()
+        existing_aggregates = self.aggregates.list()
+        workflow_data = self._get_create_workflow_data(aggregate)
+        workflow_data['name'] = ''
+        workflow_data['availability_zone'] = ''
+
+        self._test_generic_create_aggregate(workflow_data, aggregate,
+                                            existing_aggregates, 1,
+                                            u'This field is required')
+
+    def test_create_aggregate_fails_duplicated_name(self):
+        aggregate = self.aggregates.first()
+        existing_aggregates = self.aggregates.list()
+        workflow_data = self._get_create_workflow_data(aggregate)
+        expected_error_message = html \
+            .escape(u'The name "%s" is already used by another host aggregate.'
+                    % aggregate.name)
+
+        self._test_generic_create_aggregate(workflow_data, aggregate,
+                                            existing_aggregates, 1,
+                                            expected_error_message)
+
     @test.create_stubs({api.nova: ('host_list',
                                    'aggregate_details_list',
                                    'aggregate_create',
@@ -179,11 +205,27 @@ class AggregatesViewTests(test.BaseAdminViewTests):
     @mock.patch('openstack_dashboard.api.nova.extension_supported',
                 mock.Mock(return_value=False))
     @test.create_stubs({api.nova: ('aggregate_details_list',
-                                   'availability_zone_list',),
-                        api.cinder: ('tenant_absolute_limits',)})
+                                   'availability_zone_list',
+                                   'tenant_absolute_limits',),
+                        api.cinder: ('tenant_absolute_limits',),
+                        api.neutron: ('is_extension_supported',
+                                      'tenant_floating_ip_list',
+                                      'security_group_list'),
+                        api.keystone: ('tenant_list',)})
     def test_panel_not_available(self):
+        api.nova.tenant_absolute_limits(IsA(http.HttpRequest)). \
+            MultipleTimes().AndReturn(self.limits['absolute'])
         api.cinder.tenant_absolute_limits(IsA(http.HttpRequest)). \
             MultipleTimes().AndReturn(self.cinder_limits['absolute'])
+        api.neutron.\
+            is_extension_supported(IsA(http.HttpRequest), 'security-group'). \
+            MultipleTimes().AndReturn(True)
+        api.neutron.tenant_floating_ip_list(IsA(http.HttpRequest)) \
+            .AndReturn(self.floating_ips.list())
+        api.neutron.security_group_list(IsA(http.HttpRequest)) \
+            .AndReturn(self.security_groups.list())
+        api.keystone.tenant_list(IsA(http.HttpRequest)) \
+            .AndReturn(self.tenants.list())
         self.mox.ReplayAll()
 
         self.patchers['aggregates'].stop()
