@@ -16,6 +16,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.template import defaultfilters as filters
 from django.utils.http import urlencode
@@ -64,6 +65,15 @@ class UpdateFlavor(tables.LinkAction):
     classes = ("ajax-modal",)
     icon = "pencil"
 
+    def allowed(self, request, flavor):
+        return getattr(settings, 'ENABLE_FLAVOR_EDIT', False)
+
+    def get_link_url(self, flavor):
+        step = 'update_info'
+        base_url = reverse(self.url, args=[flavor.id])
+        param = urlencode({"step": step})
+        return "?".join([base_url, param])
+
 
 class UpdateMetadata(tables.LinkAction):
     name = "update_metadata"
@@ -137,7 +147,7 @@ def get_extra_specs(flavor):
 
 
 class FlavorsTable(tables.DataTable):
-    name = tables.Column('name', verbose_name=_('Flavor Name'))
+    name = tables.WrappingColumn('name', verbose_name=_('Flavor Name'))
     vcpus = tables.Column('vcpus', verbose_name=_('VCPUs'))
     ram = tables.Column(get_size,
                         verbose_name=_('RAM'),
@@ -151,6 +161,7 @@ class FlavorsTable(tables.DataTable):
     swap = tables.Column(get_swap_size,
                          verbose_name=_('Swap Disk'),
                          attrs={'data-type': 'size'})
+    rxtx_factor = tables.Column('rxtx_factor', verbose_name=_("RX/TX factor"))
     flavor_id = tables.Column('id', verbose_name=_('ID'))
     public = tables.Column("is_public",
                            verbose_name=_("Public"),
