@@ -27,4 +27,4 @@ class Info(horizon.Panel):
     policy_rules = (("compute", "context_is_admin"),
                     ("volume", "context_is_admin"),
                     ("network", "context_is_admin"),
-                    ("orchestation", "context_is_admin"),)
+                    ("orchestration", "context_is_admin"),)
