@@ -14,8 +14,8 @@
 
 from django.core.urlresolvers import reverse
 from django import http
-from mox3.mox import IgnoreArg  # noqa
-from mox3.mox import IsA  # noqa
+from mox3.mox import IgnoreArg
+from mox3.mox import IsA
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
@@ -60,19 +60,9 @@ class SystemInfoViewTests(test.BaseAdminViewTests):
     def test_index(self):
         res = self._test_base_index()
         services_tab = res.context['tab_group'].get_tab('services')
-        self.assertQuerysetEqual(
-            services_tab._tables['services'].data,
-            ['<Service: compute>',
-             '<Service: volumev2>',
-             '<Service: image>',
-             '<Service: identity (native backend)>',
-             '<Service: object-store>',
-             '<Service: network>',
-             '<Service: ec2>',
-             '<Service: metering>',
-             '<Service: orchestration>',
-             ])
-
+        self.assertIn("region", services_tab._tables['services'].data[0])
+        self.assertIn("endpoints",
+                      services_tab._tables['services'].data[0])
         self.mox.VerifyAll()
 
     def test_neutron_index(self):
