@@ -28,82 +28,26 @@ from openstack_dashboard.dashboards.project.networks.ports \
 
 
 LOG = logging.getLogger(__name__)
-VNIC_TYPES = [('normal', _('Normal')), ('direct', _('Direct')),
-              ('macvtap', _('MacVTap'))]
+VNIC_TYPES = [('normal', _('Normal')),
+              ('direct', _('Direct')),
+              ('direct-physical', _('Direct Physical')),
+              ('macvtap', _('MacVTap')),
+              ('baremetal', _('Bare Metal')),
+              ('virtio-forwarder', _('Virtio Forwarder'))]
 
 
-class CreatePort(forms.SelfHandlingForm):
-    network_name = forms.CharField(label=_("Network Name"),
-                                   widget=forms.TextInput(
-                                       attrs={'readonly': 'readonly'}),
-                                   required=False)
-    network_id = forms.CharField(label=_("Network ID"),
-                                 widget=forms.TextInput(
-                                     attrs={'readonly': 'readonly'}))
-    name = forms.CharField(max_length=255,
-                           label=_("Name"),
-                           required=False)
-    admin_state = forms.ThemableChoiceField(choices=[('True', _('UP')),
-                                                     ('False', _('DOWN'))],
-                                            label=_("Admin State"))
-    device_id = forms.CharField(max_length=100, label=_("Device ID"),
-                                help_text=_("Device ID attached to the port"),
-                                required=False)
-    device_owner = forms.CharField(max_length=100, label=_("Device Owner"),
-                                   help_text=_("Device owner attached to the "
-                                               "port"),
-                                   required=False)
+class CreatePort(project_forms.CreatePort):
     binding__host_id = forms.CharField(
         label=_("Binding: Host"),
         help_text=_("The ID of the host where the port is allocated. In some "
                     "cases, different implementations can run on different "
                     "hosts."),
         required=False)
-    specify_ip = forms.ThemableChoiceField(
-        label=_("Specify IP address or subnet"),
-        help_text=_("To specify a subnet or a fixed IP, select any options."),
-        initial=False,
-        required=False,
-        choices=[('', _("Unspecified")),
-                 ('subnet_id', _("Subnet")),
-                 ('fixed_ip', _("Fixed IP Address"))],
-        widget=forms.Select(attrs={
-            'class': 'switchable',
-            'data-slug': 'specify_ip',
-        }))
-    subnet_id = forms.ThemableChoiceField(
-        label=_("Subnet"),
-        required=False,
-        widget=forms.Select(attrs={
-            'class': 'switched',
-            'data-switch-on': 'specify_ip',
-            'data-specify_ip-subnet_id': _('Subnet'),
-        }))
-    fixed_ip = forms.IPField(
-        label=_("Fixed IP Address"),
-        required=False,
-        help_text=_("Specify the subnet IP address for the new port"),
-        version=forms.IPv4 | forms.IPv6,
-        widget=forms.TextInput(attrs={
-            'class': 'switched',
-            'data-switch-on': 'specify_ip',
-            'data-specify_ip-fixed_ip': _('Fixed IP Address'),
-        }))
     failure_url = 'horizon:admin:networks:detail'
 
     def __init__(self, request, *args, **kwargs):
         super(CreatePort, self).__init__(request, *args, **kwargs)
 
-        # prepare subnet choices and input area for each subnet
-        subnet_choices = self._get_subnet_choices(kwargs['initial'])
-        if subnet_choices:
-            subnet_choices.insert(0, ('', _("Select a subnet")))
-            self.fields['subnet_id'].choices = subnet_choices
-        else:
-            self.fields['specify_ip'].widget = forms.HiddenInput()
-            self.fields['subnet_id'].widget = forms.HiddenInput()
-            self.fields['fixed_ip'].widget = forms.HiddenInput()
-
         try:
             if api.neutron.is_extension_supported(request, 'binding'):
                 neutron_settings = getattr(settings,
@@ -140,24 +84,26 @@ class CreatePort(forms.SelfHandlingForm):
             msg = _("Unable to retrieve MAC learning state")
             exceptions.handle(self.request, msg)
 
-    def _get_subnet_choices(self, kwargs):
         try:
-            network_id = kwargs['network_id']
-            network = api.neutron.network_get(self.request, network_id)
+            if api.neutron.is_extension_supported(request, 'port-security'):
+                self.fields['port_security_enabled'] = forms.BooleanField(
+                    label=_("Port Security"),
+                    help_text=_("Enable anti-spoofing rules for the port"),
+                    initial=True,
+                    required=False)
         except Exception:
-            return []
-
-        return [(subnet.id, '%s %s' % (subnet.name_or_id, subnet.cidr))
-                for subnet in network.subnets]
+            msg = _("Unable to retrieve port security state")
+            exceptions.handle(self.request, msg)
 
     def handle(self, request, data):
+        network_id = self.initial['network_id']
         try:
             # We must specify tenant_id of the network which a subnet is
             # created for if admin user does not belong to the tenant.
-            network = api.neutron.network_get(request, data['network_id'])
+            network = api.neutron.network_get(request, network_id)
             params = {
                 'tenant_id': network.tenant_id,
-                'network_id': data['network_id'],
+                'network_id': network_id,
                 'admin_state_up': data['admin_state'],
                 'name': data['name'],
                 'device_id': data['device_id'],
@@ -178,17 +124,18 @@ class CreatePort(forms.SelfHandlingForm):
             if data.get('mac_state'):
                 params['mac_learning_enabled'] = data['mac_state']
 
+            if 'port_security_enabled' in data:
+                params['port_security_enabled'] = data['port_security_enabled']
+
             port = api.neutron.port_create(request, **params)
             msg = _('Port %s was successfully created.') % port['id']
-            LOG.debug(msg)
             messages.success(request, msg)
             return port
-        except Exception:
-            msg = _('Failed to create a port for network %s') \
-                % data['network_id']
-            LOG.info(msg)
-            redirect = reverse(self.failure_url,
-                               args=(data['network_id'],))
+        except Exception as e:
+            LOG.info('Failed to create a port for network %(id)s: %(exc)s',
+                     {'id': network_id, 'exc': e})
+            msg = _('Failed to create a port for network %s') % network_id
+            redirect = reverse(self.failure_url, args=(network_id,))
             exceptions.handle(request, msg, redirect=redirect)
 
 
@@ -207,12 +154,17 @@ class UpdatePort(project_forms.UpdatePort):
                     "cases, different implementations can run on different "
                     "hosts."),
         required=False)
+    mac_address = forms.MACAddressField(
+        label=_("MAC Address"),
+        required=False,
+        help_text=_("Specify a new MAC address for the port"))
 
     failure_url = 'horizon:admin:networks:detail'
 
     def handle(self, request, data):
+        port_id = self.initial['port_id']
         try:
-            LOG.debug('params = %s' % data)
+            LOG.debug('params = %s', data)
             extension_kwargs = {}
             if 'binding__vnic_type' in data:
                 extension_kwargs['binding__vnic_type'] = \
@@ -221,22 +173,27 @@ class UpdatePort(project_forms.UpdatePort):
             if 'mac_state' in data:
                 extension_kwargs['mac_learning_enabled'] = data['mac_state']
 
+            if 'port_security_enabled' in data:
+                extension_kwargs['port_security_enabled'] = \
+                    data['port_security_enabled']
+
             port = api.neutron.port_update(request,
-                                           data['port_id'],
+                                           port_id,
                                            name=data['name'],
                                            admin_state_up=data['admin_state'],
                                            device_id=data['device_id'],
                                            device_owner=data['device_owner'],
                                            binding__host_id=data
                                            ['binding__host_id'],
+                                           mac_address=data['mac_address'],
                                            **extension_kwargs)
-            msg = _('Port %s was successfully updated.') % data['port_id']
-            LOG.debug(msg)
+            msg = _('Port %s was successfully updated.') % port_id
             messages.success(request, msg)
             return port
-        except Exception:
-            msg = _('Failed to update port %s') % data['port_id']
-            LOG.info(msg)
+        except Exception as e:
+            LOG.info('Failed to update port %(id)s: %(exc)s',
+                     {'id': port_id, 'exc': e})
+            msg = _('Failed to update port %s') % port_id
             redirect = reverse(self.failure_url,
-                               args=[data['network_id']])
+                               args=[self.initial['network_id']])
             exceptions.handle(request, msg, redirect=redirect)
