@@ -16,7 +16,7 @@
 from django.core.urlresolvers import reverse
 from django import http
 
-from mox3.mox import IsA  # noqa
+from mox3.mox import IsA
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
@@ -84,17 +84,27 @@ class NetworkPortTests(test.BaseAdminViewTests):
     def test_port_create_get_with_mac_learning(self):
         self._test_port_create_get(mac_learning=True)
 
-    def _test_port_create_get(self, mac_learning=False, binding=False):
+    @test.create_stubs({api.neutron: ('network_get',
+                                      'is_extension_supported',)})
+    def test_port_create_get_with_port_security(self):
+        self._test_port_create_get(port_security=True)
+
+    def _test_port_create_get(self, mac_learning=False, binding=False,
+                              port_security=False):
         network = self.networks.first()
         api.neutron.network_get(IsA(http.HttpRequest),
                                 network.id)\
             .AndReturn(self.networks.first())
+
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'mac-learning')\
+            .AndReturn(mac_learning)
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
                                            'binding')\
             .AndReturn(binding)
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
-                                           'mac-learning')\
-            .AndReturn(mac_learning)
+                                           'port-security')\
+            .AndReturn(port_security)
         self.mox.ReplayAll()
 
         url = reverse('horizon:admin:networks:addport',
@@ -115,7 +125,14 @@ class NetworkPortTests(test.BaseAdminViewTests):
     def test_port_create_post_with_mac_learning(self):
         self._test_port_create_post(mac_learning=True, binding=False)
 
-    def _test_port_create_post(self, mac_learning=False, binding=False):
+    @test.create_stubs({api.neutron: ('network_get',
+                                      'is_extension_supported',
+                                      'port_create',)})
+    def test_port_create_post_with_port_security(self):
+        self._test_port_create_post(port_security=True)
+
+    def _test_port_create_post(self, mac_learning=False, binding=False,
+                               port_security=False):
         network = self.networks.first()
         port = self.ports.first()
         api.neutron.network_get(IsA(http.HttpRequest),
@@ -127,18 +144,23 @@ class NetworkPortTests(test.BaseAdminViewTests):
         api.neutron.network_get(IsA(http.HttpRequest),
                                 network.id)\
             .AndReturn(self.networks.first())
-        api.neutron.is_extension_supported(IsA(http.HttpRequest),
-                                           'binding')\
-            .AndReturn(binding)
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
                                            'mac-learning')\
             .AndReturn(mac_learning)
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'binding') \
+            .AndReturn(binding)
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'port-security')\
+            .AndReturn(port_security)
         extension_kwargs = {}
         if binding:
             extension_kwargs['binding__vnic_type'] = \
                 port.binding__vnic_type
         if mac_learning:
             extension_kwargs['mac_learning_enabled'] = True
+        if port_security:
+            extension_kwargs['port_security_enabled'] = True
         api.neutron.port_create(IsA(http.HttpRequest),
                                 tenant_id=network.tenant_id,
                                 network_id=network.id,
@@ -147,6 +169,7 @@ class NetworkPortTests(test.BaseAdminViewTests):
                                 device_id=port.device_id,
                                 device_owner=port.device_owner,
                                 binding__host_id=port.binding__host_id,
+                                mac_address=port.mac_address,
                                 **extension_kwargs)\
             .AndReturn(port)
         self.mox.ReplayAll()
@@ -157,11 +180,14 @@ class NetworkPortTests(test.BaseAdminViewTests):
                      'admin_state': port.admin_state_up,
                      'device_id': port.device_id,
                      'device_owner': port.device_owner,
-                     'binding__host_id': port.binding__host_id}
+                     'binding__host_id': port.binding__host_id,
+                     'mac_address': port.mac_address}
         if binding:
             form_data['binding__vnic_type'] = port.binding__vnic_type
         if mac_learning:
             form_data['mac_state'] = True
+        if port_security:
+            form_data['port_security_enabled'] = True
         url = reverse('horizon:admin:networks:addport',
                       args=[port.network_id])
         res = self.client.post(url, form_data)
@@ -186,10 +212,10 @@ class NetworkPortTests(test.BaseAdminViewTests):
                                 network.id)\
             .AndReturn(self.networks.first())
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
-                                           'binding')\
+                                           'mac-learning')\
             .AndReturn(True)
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
-                                           'mac-learning')\
+                                           'port-security')\
             .AndReturn(True)
         extension_kwargs = {}
         extension_kwargs['binding__vnic_type'] = \
@@ -202,6 +228,7 @@ class NetworkPortTests(test.BaseAdminViewTests):
                                 device_id=port.device_id,
                                 device_owner=port.device_owner,
                                 binding__host_id=port.binding__host_id,
+                                mac_address=port.mac_address,
                                 fixed_ips=port.fixed_ips,
                                 **extension_kwargs)\
             .AndReturn(port)
@@ -214,6 +241,7 @@ class NetworkPortTests(test.BaseAdminViewTests):
                      'device_id': port.device_id,
                      'device_owner': port.device_owner,
                      'binding__host_id': port.binding__host_id,
+                     'mac_address': port.mac_address,
                      'specify_ip': 'fixed_ip',
                      'fixed_ip': port.fixed_ips[0]['ip_address'],
                      'subnet_id': port.fixed_ips[0]['subnet_id']}
@@ -239,8 +267,15 @@ class NetworkPortTests(test.BaseAdminViewTests):
     def test_port_create_post_exception_with_mac_learning(self):
         self._test_port_create_post_exception(mac_learning=True)
 
+    @test.create_stubs({api.neutron: ('network_get',
+                                      'port_create',
+                                      'is_extension_supported',)})
+    def test_port_create_post_exception_with_port_security(self):
+        self._test_port_create_post_exception(port_security=True)
+
     def _test_port_create_post_exception(self, mac_learning=False,
-                                         binding=False):
+                                         binding=False,
+                                         port_security=False):
         network = self.networks.first()
         port = self.ports.first()
         api.neutron.network_get(IsA(http.HttpRequest),
@@ -252,17 +287,22 @@ class NetworkPortTests(test.BaseAdminViewTests):
         api.neutron.network_get(IsA(http.HttpRequest),
                                 network.id)\
             .AndReturn(self.networks.first())
-        api.neutron.is_extension_supported(IsA(http.HttpRequest),
-                                           'binding')\
-            .AndReturn(binding)
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
                                            'mac-learning')\
             .AndReturn(mac_learning)
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'binding') \
+            .AndReturn(binding)
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'port-security')\
+            .AndReturn(port_security)
         extension_kwargs = {}
         if binding:
             extension_kwargs['binding__vnic_type'] = port.binding__vnic_type
         if mac_learning:
             extension_kwargs['mac_learning_enabled'] = True
+        if port_security:
+            extension_kwargs['port_security_enabled'] = True
         api.neutron.port_create(IsA(http.HttpRequest),
                                 tenant_id=network.tenant_id,
                                 network_id=network.id,
@@ -271,6 +311,7 @@ class NetworkPortTests(test.BaseAdminViewTests):
                                 device_id=port.device_id,
                                 device_owner=port.device_owner,
                                 binding__host_id=port.binding__host_id,
+                                mac_address=port.mac_address,
                                 **extension_kwargs)\
             .AndRaise(self.exceptions.neutron)
         self.mox.ReplayAll()
@@ -282,11 +323,14 @@ class NetworkPortTests(test.BaseAdminViewTests):
                      'mac_state': True,
                      'device_id': port.device_id,
                      'device_owner': port.device_owner,
-                     'binding__host_id': port.binding__host_id}
+                     'binding__host_id': port.binding__host_id,
+                     'mac_address': port.mac_address}
         if binding:
             form_data['binding__vnic_type'] = port.binding__vnic_type
         if mac_learning:
             form_data['mac_learning_enabled'] = True
+        if port_security:
+            form_data['port_security_enabled'] = True
         url = reverse('horizon:admin:networks:addport',
                       args=[port.network_id])
         res = self.client.post(url, form_data)
@@ -305,17 +349,26 @@ class NetworkPortTests(test.BaseAdminViewTests):
     def test_port_update_get_with_mac_learning(self):
         self._test_port_update_get(mac_learning=True)
 
-    def _test_port_update_get(self, mac_learning=False, binding=False):
+    @test.create_stubs({api.neutron: ('port_get',
+                                      'is_extension_supported',)})
+    def test_port_update_get_with_port_security(self):
+        self._test_port_update_get(port_security=True)
+
+    def _test_port_update_get(self, mac_learning=False, binding=False,
+                              port_security=False):
         port = self.ports.first()
         api.neutron.port_get(IsA(http.HttpRequest),
                              port.id)\
             .AndReturn(port)
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
-                                           'binding')\
+                                           'binding') \
             .AndReturn(binding)
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
                                            'mac-learning')\
             .AndReturn(mac_learning)
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'port-security')\
+            .AndReturn(port_security)
         self.mox.ReplayAll()
 
         url = reverse('horizon:admin:networks:editport',
@@ -336,7 +389,14 @@ class NetworkPortTests(test.BaseAdminViewTests):
     def test_port_update_post_with_mac_learning(self):
         self._test_port_update_post(mac_learning=True)
 
-    def _test_port_update_post(self, mac_learning=False, binding=False):
+    @test.create_stubs({api.neutron: ('port_get',
+                                      'is_extension_supported',
+                                      'port_update')})
+    def test_port_update_post_with_port_security(self):
+        self._test_port_update_post(port_security=True)
+
+    def _test_port_update_post(self, mac_learning=False, binding=False,
+                               port_security=False):
         port = self.ports.first()
         api.neutron.port_get(IsA(http.HttpRequest), port.id)\
             .AndReturn(port)
@@ -346,17 +406,23 @@ class NetworkPortTests(test.BaseAdminViewTests):
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
                                            'mac-learning')\
             .AndReturn(mac_learning)
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'port-security')\
+            .AndReturn(port_security)
         extension_kwargs = {}
         if binding:
             extension_kwargs['binding__vnic_type'] = port.binding__vnic_type
         if mac_learning:
             extension_kwargs['mac_learning_enabled'] = True
+        if port_security:
+            extension_kwargs['port_security_enabled'] = True
         api.neutron.port_update(IsA(http.HttpRequest), port.id,
                                 name=port.name,
                                 admin_state_up=port.admin_state_up,
                                 device_id=port.device_id,
                                 device_owner=port.device_owner,
                                 binding__host_id=port.binding__host_id,
+                                mac_address=port.mac_address,
                                 **extension_kwargs)\
             .AndReturn(port)
         self.mox.ReplayAll()
@@ -367,12 +433,15 @@ class NetworkPortTests(test.BaseAdminViewTests):
                      'admin_state': port.admin_state_up,
                      'device_id': port.device_id,
                      'device_owner': port.device_owner,
-                     'binding__host_id': port.binding__host_id}
+                     'binding__host_id': port.binding__host_id,
+                     'mac_address': port.mac_address}
 
         if binding:
             form_data['binding__vnic_type'] = port.binding__vnic_type
         if mac_learning:
             form_data['mac_state'] = True
+        if port_security:
+            form_data['port_security_enabled'] = True
         url = reverse('horizon:admin:networks:editport',
                       args=[port.network_id, port.id])
         res = self.client.post(url, form_data)
@@ -392,8 +461,15 @@ class NetworkPortTests(test.BaseAdminViewTests):
     def test_port_update_post_exception_with_mac_learning(self):
         self._test_port_update_post_exception(mac_learning=True, binding=False)
 
+    @test.create_stubs({api.neutron: ('port_get',
+                                      'is_extension_supported',
+                                      'port_update')})
+    def test_port_update_post_exception_with_port_security(self):
+        self._test_port_update_post_exception(port_security=True)
+
     def _test_port_update_post_exception(self, mac_learning=False,
-                                         binding=False):
+                                         binding=False,
+                                         port_security=False):
         port = self.ports.first()
         api.neutron.port_get(IsA(http.HttpRequest), port.id)\
             .AndReturn(port)
@@ -403,17 +479,23 @@ class NetworkPortTests(test.BaseAdminViewTests):
         api.neutron.is_extension_supported(IsA(http.HttpRequest),
                                            'mac-learning')\
             .AndReturn(mac_learning)
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'port-security')\
+            .AndReturn(port_security)
         extension_kwargs = {}
         if binding:
             extension_kwargs['binding__vnic_type'] = port.binding__vnic_type
         if mac_learning:
             extension_kwargs['mac_learning_enabled'] = True
+        if port_security:
+            extension_kwargs['port_security_enabled'] = True
         api.neutron.port_update(IsA(http.HttpRequest), port.id,
                                 name=port.name,
                                 admin_state_up=port.admin_state_up,
                                 device_id=port.device_id,
                                 device_owner=port.device_owner,
                                 binding__host_id=port.binding__host_id,
+                                mac_address=port.mac_address,
                                 **extension_kwargs)\
             .AndRaise(self.exceptions.neutron)
         self.mox.ReplayAll()
@@ -424,11 +506,14 @@ class NetworkPortTests(test.BaseAdminViewTests):
                      'admin_state': port.admin_state_up,
                      'device_id': port.device_id,
                      'device_owner': port.device_owner,
-                     'binding__host_id': port.binding__host_id}
+                     'binding__host_id': port.binding__host_id,
+                     'mac_address': port.mac_address}
         if binding:
             form_data['binding__vnic_type'] = port.binding__vnic_type
         if mac_learning:
             form_data['mac_state'] = True
+        if port_security:
+            form_data['port_security_enabled'] = True
         url = reverse('horizon:admin:networks:editport',
                       args=[port.network_id, port.id])
         res = self.client.post(url, form_data)
