@@ -53,6 +53,7 @@ from openstack_dashboard.dashboards.project.instances \
     import tabs as project_tabs
 from openstack_dashboard.dashboards.project.instances \
     import workflows as project_workflows
+from openstack_dashboard.views import get_url_with_pagination
 
 LOG = logging.getLogger(__name__)
 
@@ -197,6 +198,19 @@ def console(request, instance_id):
     return http.HttpResponse(data.encode('utf-8'), content_type='text/plain')
 
 
+def auto_console(request, instance_id):
+    console_type = getattr(settings, 'CONSOLE_TYPE', 'AUTO')
+    try:
+        instance = api.nova.server_get(request, instance_id)
+        console_url = project_console.get_console(request, console_type,
+                                                  instance)[1]
+        return shortcuts.redirect(console_url)
+    except Exception:
+        redirect = reverse("horizon:project:instances:index")
+        msg = _('Unable to get console for instance "%s".') % instance_id
+        exceptions.handle(request, msg, redirect=redirect)
+
+
 def vnc(request, instance_id):
     try:
         instance = api.nova.server_get(request, instance_id)
@@ -336,7 +350,12 @@ class DetailView(tabs.TabView):
                                          args=[instance.image['id']])
         instance.volume_url = self.volume_url
         context["instance"] = instance
-        context["url"] = reverse(self.redirect_url)
+        context["url"] = get_url_with_pagination(
+            self.request,
+            project_tables.InstancesTable._meta.pagination_param,
+            project_tables.InstancesTable._meta.prev_pagination_param,
+            self.redirect_url)
+
         context["actions"] = self._get_actions(instance)
         return context
 
