@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django.core import urlresolvers
 from django.utils.translation import string_concat
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
@@ -23,7 +24,7 @@ from openstack_dashboard.usage import quotas
 
 
 class DeleteKeyPairs(tables.DeleteAction):
-    policy_rules = (("compute", "compute_extension:keypairs:delete"),)
+    policy_rules = (("compute", "os_compute_api:os-keypairs:delete"),)
     help_text = _("Removing a key pair can leave OpenStack resources orphaned."
                   " You should not remove a key pair unless you are certain it"
                   " is not being used anywhere.")
@@ -48,7 +49,23 @@ class DeleteKeyPairs(tables.DeleteAction):
         api.nova.keypair_delete(request, obj_id)
 
 
-class ImportKeyPair(tables.LinkAction):
+class QuotaKeypairMixin(object):
+    def allowed(self, request, datum=None):
+        usages = quotas.tenant_quota_usages(request, targets=('key_pairs', ))
+        count = len(self.table.data)
+        if (usages.get('key_pairs') and usages['key_pairs']['quota'] <= count):
+            if "disabled" not in self.classes:
+                self.classes = [c for c in self.classes] + ['disabled']
+                self.verbose_name = string_concat(self.verbose_name, ' ',
+                                                  _("(Quota exceeded)"))
+            return False
+        else:
+            classes = [c for c in self.classes if c != "disabled"]
+            self.classes = classes
+            return True
+
+
+class ImportKeyPair(QuotaKeypairMixin, tables.LinkAction):
     name = "import"
     verbose_name = _("Import Key Pair")
     url = "horizon:project:key_pairs:import"
@@ -56,28 +73,35 @@ class ImportKeyPair(tables.LinkAction):
     icon = "upload"
     policy_rules = (("compute", "os_compute_api:os-keypairs:create"),)
 
+    def allowed(self, request, keypair=None):
+        if super(ImportKeyPair, self).allowed(request, keypair):
+            self.verbose_name = _("Import Key Pair")
+        return True
 
-class CreateKeyPair(tables.LinkAction):
-    name = "create"
+
+class CreateLinkNG(QuotaKeypairMixin, tables.LinkAction):
+    name = "create-keypair-ng"
     verbose_name = _("Create Key Pair")
-    url = "horizon:project:key_pairs:create"
-    classes = ("ajax-modal",)
+    url = "horizon:project:key_pairs:index"
+    classes = ("btn-launch",)
     icon = "plus"
     policy_rules = (("compute", "os_compute_api:os-keypairs:create"),)
 
+    def get_default_attrs(self):
+        url = urlresolvers.reverse(self.url)
+        ngclick = "modal.createKeyPair({ successUrl: '%s' })" % url
+        self.attrs.update({
+            'ng-controller': 'KeypairController as modal',
+            'ng-click': ngclick
+        })
+        return super(CreateLinkNG, self).get_default_attrs()
+
+    def get_link_url(self, datum=None):
+        return "javascript:void(0);"
+
     def allowed(self, request, keypair=None):
-        usages = quotas.tenant_quota_usages(request)
-        count = len(self.table.data)
-        if (usages.get('key_pairs')
-                and usages['key_pairs']['quota'] <= count):
-            if "disabled" not in self.classes:
-                self.classes = [c for c in self.classes] + ['disabled']
-                self.verbose_name = string_concat(self.verbose_name, ' ',
-                                                  _("(Quota exceeded)"))
-        else:
+        if super(CreateLinkNG, self).allowed(request, keypair):
             self.verbose_name = _("Create Key Pair")
-            classes = [c for c in self.classes if c != "disabled"]
-            self.classes = classes
         return True
 
 
@@ -102,6 +126,6 @@ class KeyPairsTable(tables.DataTable):
     class Meta(object):
         name = "keypairs"
         verbose_name = _("Key Pairs")
-        table_actions = (CreateKeyPair, ImportKeyPair, DeleteKeyPairs,
+        table_actions = (CreateLinkNG, ImportKeyPair, DeleteKeyPairs,
                          KeypairsFilterAction,)
         row_actions = (DeleteKeyPairs,)
