@@ -15,7 +15,7 @@
 
 from django.core.urlresolvers import reverse
 from django import http
-from mox3.mox import IsA  # noqa
+from mox3.mox import IsA
 
 from horizon.workflows import views
 
@@ -34,8 +34,7 @@ form_data_subnet = net_tests.form_data_subnet
 class NetworkSubnetTests(test.TestCase):
 
     @test.create_stubs({api.neutron: ('network_get',
-                                      'subnet_get',
-                                      'is_extension_supported')})
+                                      'subnet_get',)})
     def test_subnet_detail(self):
         network = self.networks.first()
         subnet = self.subnets.first()
@@ -65,6 +64,55 @@ class NetworkSubnetTests(test.TestCase):
 
         self.assertRedirectsNoFollow(res, NETWORKS_INDEX_URL)
 
+    @test.create_stubs({api.neutron: ('network_get',
+                                      'subnet_get', 'subnetpool_get',
+                                      'is_extension_supported')})
+    def test_subnet_detail_with_subnetpool(self):
+        network = self.networks.first()
+        subnet = self.subnets.first()
+        subnetpool = self.subnetpools.first()
+        subnet.subnetpool_id = subnetpool.id
+
+        api.neutron.network_get(IsA(http.HttpRequest), network.id)\
+            .MultipleTimes().AndReturn(network)
+        api.neutron.subnet_get(IsA(http.HttpRequest), subnet.id)\
+            .AndReturn(subnet)
+        api.neutron.is_extension_supported(
+            IsA(http.HttpRequest), 'subnet_allocation').AndReturn(True)
+        api.neutron.subnetpool_get(IsA(http.HttpRequest), subnetpool.id)\
+            .AndReturn(subnetpool)
+        self.mox.ReplayAll()
+
+        url = reverse(DETAIL_URL, args=[subnet.id])
+        res = self.client.get(url)
+
+        self.assertTemplateUsed(res, 'horizon/common/_detail.html')
+        self.assertEqual(subnet.id, res.context['subnet'].id)
+        self.assertEqual(subnetpool.id, res.context['subnet'].subnetpool_id)
+        self.assertEqual(subnetpool.name,
+                         res.context['subnet'].subnetpool_name)
+
+    @test.create_stubs({api.neutron: ('network_get',
+                                      'subnet_get')})
+    def test_subnet_detail_with_subnetpool_prefixdelegation(self):
+        network = self.networks.first()
+        subnet = self.subnets.first()
+        subnet.subnetpool_id = 'prefix_delegation'
+
+        api.neutron.network_get(IsA(http.HttpRequest), network.id)\
+            .MultipleTimes().AndReturn(network)
+        api.neutron.subnet_get(IsA(http.HttpRequest), subnet.id)\
+            .AndReturn(subnet)
+        self.mox.ReplayAll()
+
+        url = reverse(DETAIL_URL, args=[subnet.id])
+        res = self.client.get(url)
+
+        self.assertTemplateUsed(res, 'horizon/common/_detail.html')
+        self.assertEqual(subnet.id, res.context['subnet'].id)
+        self.assertEqual('prefix_delegation',
+                         res.context['subnet'].subnetpool_id)
+
     @test.create_stubs({api.neutron: ('network_get',
                                       'is_extension_supported',
                                       'subnetpool_list')})
@@ -80,7 +128,7 @@ class NetworkSubnetTests(test.TestCase):
             AndReturn(self.subnetpools.list())
         self.mox.ReplayAll()
 
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[network.id])
         res = self.client.get(url)
 
@@ -90,7 +138,7 @@ class NetworkSubnetTests(test.TestCase):
                                       'subnet_create',
                                       'is_extension_supported',
                                       'subnetpool_list')})
-    def test_subnet_create_post(self, test_with_subnetpool=False):
+    def test_subnet_create_post(self):
         network = self.networks.first()
         subnet = self.subnets.first()
         api.neutron.network_get(IsA(http.HttpRequest),
@@ -113,7 +161,7 @@ class NetworkSubnetTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = form_data_subnet(subnet)
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -150,7 +198,7 @@ class NetworkSubnetTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = form_data_subnet(subnet)
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -185,7 +233,7 @@ class NetworkSubnetTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = form_data_subnet(subnet, gateway_ip=None)
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -210,7 +258,7 @@ class NetworkSubnetTests(test.TestCase):
             form_data['subnetpool'] = subnetpool.id
         form_data.update(form_data_subnet(subnet, allocation_pools=[]))
 
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -225,8 +273,7 @@ class NetworkSubnetTests(test.TestCase):
                                       'subnet_create',
                                       'is_extension_supported',
                                       'subnetpool_list')})
-    def test_subnet_create_post_subnet_exception(self,
-                                                 test_with_subnetpool=False):
+    def test_subnet_create_post_subnet_exception(self):
         network = self.networks.first()
         subnet = self.subnets.first()
         api.neutron.network_get(IsA(http.HttpRequest),
@@ -248,7 +295,7 @@ class NetworkSubnetTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = form_data_subnet(subnet, allocation_pools=[])
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -283,7 +330,7 @@ class NetworkSubnetTests(test.TestCase):
         cidr = '2001:0DB8:0:CD30:123:4567:89AB:CDEF/60'
         form_data.update(form_data_subnet(subnet, cidr=cidr,
                                           allocation_pools=[]))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -323,7 +370,7 @@ class NetworkSubnetTests(test.TestCase):
         gateway_ip = '2001:0DB8:0:CD30:123:4567:89AB:CDEF'
         form_data.update(form_data_subnet(subnet, gateway_ip=gateway_ip,
                                           allocation_pools=[]))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -359,7 +406,7 @@ class NetworkSubnetTests(test.TestCase):
         allocation_pools = '10.0.0.2'
         form_data.update(form_data_subnet(subnet,
                                           allocation_pools=allocation_pools))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -398,7 +445,7 @@ class NetworkSubnetTests(test.TestCase):
         allocation_pools = '10.0.0.2,10.0.0.3,10.0.0.4'
         form_data.update(form_data_subnet(subnet,
                                           allocation_pools=allocation_pools))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -437,7 +484,7 @@ class NetworkSubnetTests(test.TestCase):
         allocation_pools = '10.0.0.2,invalid_address'
         form_data.update(form_data_subnet(subnet,
                                           allocation_pools=allocation_pools))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -476,7 +523,7 @@ class NetworkSubnetTests(test.TestCase):
         allocation_pools = '10.0.0.2/24,10.0.0.5'
         form_data.update(form_data_subnet(subnet,
                                           allocation_pools=allocation_pools))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -515,7 +562,7 @@ class NetworkSubnetTests(test.TestCase):
         allocation_pools = '10.0.0.254,10.0.0.2'
         form_data = form_data_subnet(subnet,
                                      allocation_pools=allocation_pools)
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -555,7 +602,7 @@ class NetworkSubnetTests(test.TestCase):
         form_data.update(form_data_subnet(subnet,
                                           dns_nameservers=dns_nameservers,
                                           allocation_pools=[]))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -596,7 +643,7 @@ class NetworkSubnetTests(test.TestCase):
         form_data.update(form_data_subnet(subnet,
                                           allocation_pools=[],
                                           host_routes=host_routes))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -637,7 +684,7 @@ class NetworkSubnetTests(test.TestCase):
         form_data.update(form_data_subnet(subnet,
                                           allocation_pools=[],
                                           host_routes=host_routes))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -678,7 +725,7 @@ class NetworkSubnetTests(test.TestCase):
         form_data.update(form_data_subnet(subnet,
                                           host_routes=host_routes,
                                           allocation_pools=[]))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -718,7 +765,7 @@ class NetworkSubnetTests(test.TestCase):
         form_data.update(form_data_subnet(subnet,
                                           host_routes=host_routes,
                                           allocation_pools=[]))
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -757,7 +804,7 @@ class NetworkSubnetTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = form_data_subnet(subnet)
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
@@ -794,7 +841,7 @@ class NetworkSubnetTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = form_data_subnet(subnet)
-        url = reverse('horizon:project:networks:addsubnet',
+        url = reverse('horizon:project:networks:createsubnet',
                       args=[subnet.network_id])
         res = self.client.post(url, form_data)
 
