@@ -36,7 +36,8 @@ class RouterMixin(object):
     })
     def _get_detail(self, router, extraroute=True, lookup_l3=False,
                     support_l3_agent=True):
-        api.neutron.is_extension_supported(IsA(http.HttpRequest), 'extraroute')\
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'extraroute')\
             .MultipleTimes().AndReturn(extraroute)
         if lookup_l3:
             api.neutron.is_extension_supported(IsA(http.HttpRequest),
@@ -50,8 +51,8 @@ class RouterMixin(object):
         self._mock_external_network_get(router)
         if lookup_l3 and support_l3_agent:
             agent = self.agents.list()[1]
-            api.neutron.list_l3_agent_hosting_router(IsA(http.HttpRequest), router.id)\
-                .AndReturn([agent])
+            api.neutron.list_l3_agent_hosting_router(
+                IsA(http.HttpRequest), router.id).AndReturn([agent])
         self.mox.ReplayAll()
 
         res = self.client.get(reverse('horizon:%s'
@@ -770,7 +771,8 @@ class RouterRouteTests(RouterMixin, test.TestCase):
         pre_router = self.routers_with_routes.first()
         post_router = copy.deepcopy(pre_router)
         route = post_router['routes'].pop()
-        api.neutron.is_extension_supported(IsA(http.HttpRequest), 'extraroute')\
+        api.neutron.is_extension_supported(IsA(http.HttpRequest),
+                                           'extraroute')\
             .MultipleTimes().AndReturn(True)
         api.neutron.router_get(IsA(http.HttpRequest),
                                pre_router.id).AndReturn(pre_router)
