@@ -76,6 +76,7 @@
       .setItemInTransitionFunction(imagesService.isInTransition)
       .setProperties(imageProperties(imagesService, statuses))
       .setListFunction(imagesService.getImagesPromise)
+      .setNeedsFilterFirstFunction(imagesService.getFilterFirstSettingPromise)
       .tableColumns
       .append({
         id: 'owner',
@@ -147,7 +148,7 @@
           {label: gettext('Public'), key: 'public'},
           {label: gettext('Private'), key: 'private'},
           {label: gettext('Shared With Project'), key: 'shared'},
-          {label: gettext('Unknown'), key: 'unknown'}
+          {label: gettext('Community'), key: 'community'}
         ]
       })
       .append({
@@ -253,7 +254,7 @@
       container_format: { label: gettext('Container Format'), filters: ['uppercase'] },
       disk_format: { label: gettext('Disk Format'), filters: ['noValue', 'uppercase'] },
       is_public: { label: gettext('Is Public'), filters: ['yesno'] },
-      type: { label: gettext('Type'), filters: [imagesService.imageType] },
+      type: { label: gettext('Type')},
       'protected': { label: gettext('Protected'), filters: ['yesno'] },
       size: { label: gettext('Size'), filters: ['bytes'] },
       status: { label: gettext('Status'), values: statuses }
@@ -277,7 +278,8 @@
   config.$inject = [
     '$provide',
     '$windowProvider',
-    '$routeProvider'
+    '$routeProvider',
+    'horizon.app.core.detailRoute'
   ];
 
   /**
@@ -288,7 +290,7 @@
    * @description Routes used by this module.
    * @returns {undefined} Returns nothing
    */
-  function config($provide, $windowProvider, $routeProvider) {
+  function config($provide, $windowProvider, $routeProvider, detailRoute) {
     var path = $windowProvider.$get().STATIC_URL + 'app/core/images/';
     $provide.constant('horizon.app.core.images.basePath', path);
 
@@ -309,7 +311,7 @@
     });
 
     function goToAngularDetails(params) {
-      return 'project/ngdetails/OS::Glance::Image/' + params.id;
+      return detailRoute + 'OS::Glance::Image/' + params.id;
     }
   }
 
