@@ -19,11 +19,13 @@ URL patterns for the OpenStack Dashboard.
 
 from django.conf import settings
 from django.conf.urls import include
-from django.conf.urls.static import static  # noqa
+from django.conf.urls.static import static
 from django.conf.urls import url
-from django.contrib.staticfiles.urls import staticfiles_urlpatterns  # noqa
+from django.contrib.staticfiles.urls import staticfiles_urlpatterns
 from django.views import defaults
 
+from horizon.browsers import views as browsers_views
+
 from openstack_dashboard.api import rest
 from openstack_dashboard.test.jasmine import jasmine
 from openstack_dashboard import views
@@ -36,6 +38,9 @@ urlpatterns = [
     url(r'^api/', include(rest.urls)),
     url(r'^jasmine/(.*?)$', jasmine.dispatcher),
     url(r'', include(horizon.urls)),
+    url(r'^ngdetails/',
+        browsers_views.AngularDetailsView.as_view(),
+        name='ngdetails'),
 ]
 
 # Development static app and project media serving using the staticfiles app.
